pub struct UpdateScheduleRecord {
pub availability: Option<Box<AvailabilityRecord>>,
pub warnings: Option<Vec<Warning>>,
pub errors: Option<Vec<Error>>,
}Expand description
UpdateScheduleRecord : UpdateScheduleRecord entity contains the AvailabilityRecord if there is an error/warning while performing the requested operation on it.
Fields
availability: Option<Box<AvailabilityRecord>>warnings: Option<Vec<Warning>>A list of warnings returned in the sucessful execution response of an API request.
errors: Option<Vec<Error>>A list of error responses returned when a request is unsuccessful.
Implementations
sourceimpl UpdateScheduleRecord
impl UpdateScheduleRecord
sourcepub fn new() -> UpdateScheduleRecord
pub fn new() -> UpdateScheduleRecord
UpdateScheduleRecord entity contains the AvailabilityRecord if there is an error/warning while performing the requested operation on it.